from typing import Any
from typing import Dict

from .client import DefaultClient  # noqa


RequestFixtures = Dict[str, Dict[str, Dict[str, Any]]]
